#
# spec file for package live555
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           live555
Version:        2015.10.12
Release:        14.1
Summary:        LIVE555 Streaming Media
License:        LGPL-2.1
Group:          System/Libraries
Url:            http://www.live555.com/liveMedia/
Source:         http://www.live555.com/liveMedia/public/live.%{version}.tar.gz
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         %{name}-fpic.patch
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This code forms a set of C++ libraries for multimedia streaming,
using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries
can be used to build streaming applications

%package devel
Summary:        LIVE555 Streaming Media
Group:          Development/Languages/C and C++
# Actually, live555 is a devel package only. Headers, code and a static lib is all there is.
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description devel
This code forms a set of C++ libraries for multimedia streaming,
using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries
can be used to build streaming applications

%prep
%setup -q -n live
%patch0 -p1

%build
export CFLAGS="%{optflags}"
export CPPFLAGS="%{optflags}"
./genMakefiles linux
make %{?_smp_mflags}

%install
install -d -m 755 %{buildroot}%{_libdir}/live
install -d -m 755 %{buildroot}%{_includedir}
find . -type f -name "*.a" -exec install -m 644 {} %{buildroot}%{_libdir}/live \;
for fld in liveMedia groupsock BasicUsageEnvironment UsageEnvironment; do
  install -d -m 755 %{buildroot}%{_includedir}/$fld
  cp -rL $fld/include/* %{buildroot}%{_includedir}/$fld
done

# creates support file for pkg-config
mkdir %{buildroot}/%{_libdir}/pkgconfig
tee %{buildroot}/%{_libdir}/pkgconfig/live555.pc << "EOF"
prefix=%{_prefix}
exec_prefix=${prefix}
libdir=${exec_prefix}/%{_lib}
includedir=${prefix}/include

Name: live555
Description: Multimedia streaming libraries
Version: %{version}
Libs: -L${libdir}/live -lliveMedia -lUsageEnvironment -lgroupsock -lBasicUsageEnvironment
Cflags: -I${includedir}/liveMedia -I${includedir}/UsageEnvironment -I${includedir}/groupsock -I${includedir}/BasicUsageEnvironment
EOF

%files devel
%defattr(-,root,root)
%{_libdir}/live/
%{_includedir}/liveMedia/
%{_includedir}/groupsock/
%{_includedir}/BasicUsageEnvironment/
%{_includedir}/UsageEnvironment/
%{_libdir}/pkgconfig/live555.pc

%changelog
* Fri Oct 16 2015 aloisio@gmx.com
- Update to version 2015.10.12:
  * The change that we made to the "ProxyServerMediaSession" code
    in version 2015.07.31 (to reset the proxy server's state if
    a back-end "SETUP" command fails) was too aggressive; it was
    deleting the "ProxyServerMediaSubsession" object.  This was
    a problem, because "SETUP" commands can be called from within
    "ProxyServerMediaSubsession::createNewStreamSource()".
    Instead, we now deal with a failed back-end "SETUP" command
    simply by resetting the 'back-end' connection. (Thanks to
    Hardik Sangani for reporting this issue.)
- 2015.09.24:
  * Fixed a bug in "RTSPClient" that could cause a crash if the
    TCP connection was lost while resending a RTSP command.
    (Thanks to ChaSeop Im for reporting this.)
  * Moved some more generic 'media server' functionality from
    "RTSPServer" to its parent class "GenericMediaServer".
  * Added a new pure virtual function "getRTPSinkandRTCP()"
    to "ServerMediaSubsession" to allow callers to get ('const')
    access to a stream's "RTPSink" and/or "RTCPInstance" (and
    thus their corresponding "Groupsock" objects) after the
    stream has been created (using "getStreamParameters()".
  * Updated "Groupsock" to allow for the possibility of there
    being more than one 'destRecord' for each sessionId.
    (This is something that doesn't happen in the normal case;
    it's only a special case for WebRTC.)
- 2015.08.07:
  * If a "RTCPInstance" happens to have both a source and a sink
    (an unusual situation), we now include both "SR" and "RR"
    reports in each outgoing RTCP report packet.
  * When a "RTPSink" is being closed, we no longer turn off
    background reading on its 'groupsock' (because, being a
    "RTPSink", we never turned it on), just in case the
    'groupsock' is also being shared with something else
    (e.g., a "RTPSource") that does background read handling).
- 2015.08.06:
  * Fixed a bug that would cause the destruction of a
    "RTCPInstance" that was sharing a 'groupsock'
    with a "RTPSource" (i.e., for multiplexed RTP and RTCP) to
    stop the "RTPSource" from continuing to receive incoming RTP
    packets.  This normally wasn't a major problem, because the
    destruction of the "RTCPInstance" was usually followed
    immediately by the destruction of the "RTPSource".
    However, it's also possible for the "RTPSource" to stay alive
    long after the "RTCPInstance" is deleted; in this case things
    will now work correctly.
- 2015.07.31:
  * Fixed a minor memory leak in the "ProxyServerMediaSession"
    code ("PresentationTimeSessionNormalizer"s and
    "PresentationTimeSubsessionNormalizer"s weren't being deleted
    properly). (Thanks to Dnyanesh Gate for reporting this.)
  * Made the "ProxyServerMediaSession" code a bit more
    bullet-proof, by resetting the 'back-end' connection if a
    "SETUP" command fails. (Thanks to Craig Matsuura for providing
    a real-world example of "SETUP" failing.)
  * Fixed the 'estimated bitrate' values in
    "testMPEG1or2VideoReceiver.cpp" and
    "testMPEG2TransportReceiver.cpp" to match those in the
    corresponding "test*Streamer.cpp" files.
    (Thanks to Alex Anderson for reporting this.)
- 2015.07.23:
  * Fixed a potential buffer overflow bug in "RTSPServer".
    (Thanks to "an anonymous researcher working with Beyond
    Security's SecuriTeam Secure Disclosure" for discovering this.)
- 2015.07.19:
  * Fixed a bug in "RTPInterface::sendDataOverTCP()"; it was
    disabling transmission on its socket if the "send()" call
    failed.  We now do this only if the error was not "EAGAIN".
    (Thanks to Erik Oomen for bringing this to our attention.)
  * Changed "QuickTimeFileSink" to try to work around an issue with
    QuickTime sometimes complaining about the frame number in the
    last 'sync frame' being 'out of range'.
  * Changed the parameter signature for
    "ProxyServerMediaSession::createNew()" (and the
    "ProxyServerMediaSession" constructor) to take a
    "GenericMediaServer*" rather than a "RTSPServer" as parameter.
    This makes it possible to create proxy servers that use protocols
    other than RTSP at the 'front-end'.  (The 'back-end' protocol will
    still be RTSP, however.)
  * Defined a new class "MediaTranscodingTable" that can be used to
    generate "FramedFilter" (subclass) objects that perform media
    transcoding.  Added a parameter of this type (with default value
    NULL) to the "ProxyServerMediaSession" constructor and
    "createNew()" function.  This makes it possible to - if you wish
  - add transcoding functionality to a proxy server.  (This feature
    is still experimental, and might be changed in the future.)
  * Added optional "initialPortNum" and "multiplexRTCPWithRTP"
    parameters to the "ProxyServerMediaSession" constructor - to be
    passed to the "ProxyServerMediaSubsession" objects that it creates.
    This allows subclasses to change these parameters if they wish.
  * Updated "ProxyServerMediaSession" to make it possible for
    subclasses to create subclasses of "Groupsock" and/or
    "RTCPInstance", if they wish.
- 2015.06.25:
  * Changed the definition of the "doEventLoop()" "watchVariable" to
    make it 'volatile'. (Ditto for the "fTriggersAwaitingHandling"
    field in the "BasicTaskScheduler" implementation.) This is to
    alleviate a concern about aggressive optimizing compilers
    possibly generating incorrect code.  (Thanks to Remi
    Denis-Courmont for bringing this issue to our attention.)
- 2015.06.24:
  * Updated the implementation of "GenericMediaServer" to move the
    code that removes and deletes all "ClientConnection",
    "ClientSession", and "ServerMediaS(ubs)ession" objects from the
    "GenericMediaServer" destructor to a member function "cleanup()".
    This member function MUST be called from the destructor of any
    subclass of "GenericMediaServer".  (Putting this code in the
    destructor of "GenericMediaServer" itself was a bug, because the
    "ClientConnection", "ClientSession", and
    "ServerMediaS(ubs)ession" objects may themselves have been
    subclassed, and there may be a problem deleting them after the
    "GenericMediaServer" subclass destructor has already been called.
    (Thanks to Christopher Benne for noting this.)
  * Fixed the way that "RTSPClient" handles responses to
  "GET_PARAMETER" to properly allow for possible additional
    pipelined responses appearing afterwards.
    (Thanks to Paul Clark for identifying this problem.)
  * Moved the "ClientSession" liveness checking/timeout mechanism
    from "RTSPServer" to its new abstract base class
    "GenericMediaServer".  (The API and functionality of the
    "RTSPServer" class remains unchanged.)
  * Updated the "OnDemandServerMediaSubsession" code to make it
    possible for subclasses to create and use subclasses of
    "RTCPInstance".
  * Undid the change that we made to "RTSPClient.hh" in the
    previous version.  There is no longer a demonstrated need to
    make "RTSPClient::connectToServer()" virtual.
  * Made a syntactic change to "MatroskaFile.cpp" to eliminate
    some compiler warnings.
- 2015.06.21:
  * Updated "RTSPClient" to put "port=" rather than "client_port="
    in "Transport:" headers when requesting a multicast stream,
    in accordance with RFC 2326.
    (Thanks to Julian Scheel for noting this.)
  * Updated "MultiFramedRTPSource" so that it doesn't deliver
    0-length frames to the downstream object - in case the
    downstream object interprets this as being an error.
    (Thanks to Julian Scheel for the suggestion.)
  * Made the member function "RTSPClient::connectToServer()"
    virtual, in response to a request from a developer who wanted
    to reimplement this in their "RTSPClient" subclass.
  * Changed the "Groupsock::output()" function to no longer
    take a 'TTL' parameter. (Instead, we now use the TTL (usually
    255) that was provided when the "Groupsock" object was
    created.)
  * Cleaned up the "GroupEId" class that's used by "Groupsock".
    (Previously, that class had some extra, experimental
    functionality that turned out not to be useful.)
  * Cleaned up the "destRecord" structure that's used in
    "Groupsock" to represent the (possibly multiple) destinations
    for each "Groupsock" object.
  * Updated the "groupsock" library and
    "OnDemandServerMediaSubsession" to better support (in some
    future release) sockets whose destination endpoints are set
    via STUN packet exchanges.
- 2015.06.11:
  * Fixed a bug in "RTSPClient" that had accidentally been
    introduced in version - 2015.06.04 that prevented "Session:"
    headers from being included in some requests.
- 2015.06.10:
  * Fixed the return type of the "createNewClientConnection()"
    virtual function, redefined in
    "RTSPServerSupportingHTTPStreaming".
  * More changes to satisfy anal-retentive compilers.
  * Removed the "DarwinInjector" code; that functionality has
    not been supported for some time.
- 2015.06.09a:
  * More changes to supposedly satisfy anal-retentive compilers.
- 2015.06.09:
  * Added some "friend" declarations to "GenericMediaServer.hh"
    and "RTSPServer.hh" in an attempt to placate an anal-retentive
    Windows compiler.  (Issue reported by Deanna Earley.)
- 2015.06.07:
  * Restructured the "RTSPServer" class into an abstract base
    class "GenericMediaServer" and a subclass "RTSPServer".
    This makes it possible to develop other kinds of media server
    that use the same "ServerMediaSession"/"ServerMediaSubsession"
    objects to represent the stream(s) that they serve, but using
    protocols other than RTSP.
  * Added a new virtual function "createGroupsock" to
    "OnDemandServerMediaSubsession". This makes it possible for
    subclasses of "OnDemandServerMediaSubsession" to automatically
    use subclasses of "Groupsock" (e.g., those that implement
    STUN/DTLS).
  * Moved the "ignoreSigPipeOnSocket()" function from
    "RTSPCommon.hh" ("liveMedia" library) to "GroupsockHelper.hh"
    ("groupsock" library), because the function is not specific to
    RTSP.
- 2015.06.04:
  * Added optional support for including the RTSP "Speed:" header
    in "PLAY" requests. (Thanks to Sarma Kolavasi.)
  * Updated the implementation of "setResultErrMsg()" in
    "BasicUsageEnvironment" to work properly in Windows.
    (Thanks to Stas Tsymbalov.)
- 2015.05.31:
  * Updated the "ProxyServerMediaSession" code to recover better
    if a back-end RTSP "PLAY" command fails (for whatever reason).
    Should this happen, we now reset the connection to the
    'back-end' server.  (This will cause the initial 'front-end'
    client connection (that caused the "PLAY" command to be sent)
    to fail, but subsequent 'front-end' client requests will now
    have a better chance of succeeding.)
- 2015.05.28:
  * Fixed a bug in error reporting in the "groupsock" library.
    In a couple of places, we were using the result of
    "getResultMsg()" directly in a call to "setResultMsg()", but
    unfortunately those functions are implemented (at least in
    "BasicUsageEnvironment") using the same buffer.
    (Thanks to Stas Tsymbalov for reporting this.)
  * Updated the "MPEGVideoStreamFramer" class (and thereby its
    subclasses, including "H264VideoStreamFramer" to implement
    the "doStopGettingFrames()" virtual function by calling
    "flushInput()".  This should fix a potential problem whereby
    these classes might not work correctly if the downstream
    reader calls "stopPlaying()", and then resumes reading.
    (Thanks to Stas Tsymbalov for bringing this issue to our
    attention.)
- 2015.05.25:
  * Fixed a bug in "StreamReplicator::removeStreamReplica()":
    It should have been calling "deactivateStreamReplica()"
  * before* possibly deleting the "StreamReplicator" object
    (if this was the last replica, and
    "fDeleteWhenLastReplicaDies" was True).
    (Thanks to Stas Tsymbalov for reporting this.)
  * Fixed some potential problems with "StreamReplica"
    deactivation.  (Thanks to Stas Tsymbalov.)
  * Updated the "RTSPServer" implementation to call
    "ignoreSigPipeOnSocket()" on 'client connection' sockets,
    rather than just on the main server socket.  This is to
    ensure that the server doesn't get killed if a client -
    running on the same host - gets killed.  (Note that, because
    of this fix, it should never be necessarily to set the
    "MSG_NOSIGNAL" flag on any of our calls to "send()".)
- 2015.05.12:
  * Updated the previous revision to change the order in which
    fields are deleted in the "RTSPServer" destructor, to avoid
    a possible crash if "RTSPServer" objects are deleted.
    (Thanks to ChaSeop Im for noting the problem.)
- 2015.05.03:
  * Updated the "RTSPServer" implementation to fix a bug in
    RTP/RTCP-over-TCP streaming. Before, if the
    "RTSPClientConnection" object closed before the
    "RTSPClientSession" object, and the TCP connection was also
    being used for RTP/RTCP-over-TCP streaming, then the streaming
    state (in the "RTSPClientSession") would stay alive, even
    though the TCP socket had closed (and the socket number
    possibly reused for a subsequent connection). This could cause
    a problem when the "RTSPClientSession" was later reclaimed
    (due to inactivity). Now, whenever a "RTSPClientConnection"
    object is closed (due to the RTSP TCP connection closing), we
    make sure that we also close any stream that had been using
    the same TCP connection for RTP/RTCP-over-TCP streaming.
    (Thanks to Kirill Zhegulev for noting this issue.)
  * Removed extraneous comments near the top of
    "testProgs/registerRTSPStream".
- 2015.04.22:
  * Updated "config.iphone" and "config.iphone-simulator" to work
    with the latest Xcode. (Thanks to Braden Ackerman.)
  * Fixed a rare memory leak in "MultiFramedRTPSource" that might
    occur if it's reading an incoming packet over TCP - requiring
    >1 read for the packet - and the "MultiFramedRTPSource" gets
    closed or paused while this is happening.
    (Thanks to Kirill Zhegulev for noting this.)
- 2015.04.16:
  * Added the "f" (force symbolic link) flag to the "ln" command
    in the "make install" Makefile rules, in case you're
    reinstalling the same version of a library.
    (Thanks to Luca Ceresoli for noting the need for this.)
- 2015.04.15:
  * Removed the previous (20 kByte) hard-wired limitation in the
    size of incoming packets for "MultiFramedRTPSource".  (Now,
    any size packet up to the maximum size of 65535 can be
    handled.)
  * Added a (u_int16_t) field "desiredMaxIncomingPacketSize" to
    "RTSPClient".  If set to a value >0, then a "Blocksize:"
    header with this value (minus an allowance for IP, UDP, and
    RTP headers) will be sent with each "SETUP" request.
    (Thanks to Deanna Earley for noting the optional RTSP
    "Blocksize" header.)
- 2015.04.01:
  * By default, "H264or5VideoStreamDiscreteFramer" sets
    "fPictureEndMarker" (and thus the RTP 'M' bit) if the NAL
    unit is VCL.  Because this isn't always the right thing to do
    (e.g., if we're delivering multiple 'slice' NAL units per
    'access unit' (picture)), we now move this test into a virtual
    function
    "H264or5VideoStreamDiscreteFramer::nalUnitEndsAccessUnit()".
    If desired, you can implement a subclass that redefines this
    virtual function. (Thanks to Chris Richardson for bringing
    this issue to our attention.)
  * Made a minor syntactic change to
    "ProxyServerMediaSubsession.cpp" to ensure that it compiles
    with some old versions of VC++.
- 2015.03.19:
  * Updated the "RTSPClient" code for handling a
    "WWW-Authenticate:" header in a "401 Unauthorized" response.
    We now check for the "stale=TRUE" parameter.  If it's set,
    then we resend the command, even if we already handled an
    earlier "WWW-Authenticate:" header. (Thanks to Deanna Earley
    for noting the need to handle "stale=TRUE".)
- 2015.03.16:
  * Made a small change to the "BasicTaskScheduler"
    implementation to reduce the likelihood of a race condition
    with external thread(s) calling "triggerEvent()".
- 2015.03.06a:
  * Oops - forgot to add '\0'-termination to the previous fix.
- 2015.03.06:
  * Updated "RTSPClient" to decode %%-encoded characters, should
    they appear in the <username> and/or <password> fields in a
    "rtsp://" URL. (Thanks to Deanna Earley for suggesting this.)
- 2015.03.01:
  * Updated the "H264or5VideoRTPSink" implementation to make sure
    that any stale fragmented data is flushed (discarded) if a
    server's stream is paused.  This ensures that - after we
    resume from the pause - that we never stream data with old
    presentation times. (Thanks to Gilles Chanteperdrix for
    discovering and reporting this issue.)
- 2015.02.26:
  * Fixed a bug in "ProxyServerMediaSubsession" that could cause a
    crash if the parent "ProxyServerMediaSession" object is
    removed from the RTSP server and deleted. (Thanks to Sergio ?
    for first reporting this problem.  Thanks to Chiung Ikhwan
    for discovering the source of the bug.)
- 2015.02.23:
  * Fixed a bug in
    "OnDemandServerMediaSubsession::getCurrentNPT()".
    (Thanks to Gilles Chanteperdrix for noting this.)
- 2015.02.17:
  * Latest version of the "LIVE555 Streaming Media" code
  (reinstalled due to a server crash).
- 2015.02.13:
  * Oops - removed the "#define DEBUG" that had inadvertently
    been left in "RTCP.cpp" in the previous version.
- 2015.02.12:
  * Updated the previous release of "RTCP.cpp" to ensure that it
    will compile for Windows.
- 2015.02.10:
  * Added experimental support for sending RTCP "APP" packets,
    and handling incoming RTCP "APP" packets.  (Thanks to Nick
    Ogden for suggesting this, and providing an example
    implementation.)
- 2015.02.05:
  * Made the "ProxyServerMediaSession" code a bit more
    'bulletproof'.
- 2015.02.04:
  * Fixed a bug in "DigestAuthentication" that could cause the
    proxy server code to crash if it was given a username and
    password for its 'back end' server.
    (Thanks to Sergio Andrade  for reporting this.)
  * Fixed a minor bug in "MatroskaFileParser".
  * Did some syntactic cleanup on a few files to avoid compiler
    warnings with the newest version of "gcc".
* Sat Jan 31 2015 aloisio@gmx.com
- fixed paths in live555.pc
- update to version 2015.01.27:
  * Fixed a bug in "MPEG2TransportStreamFromESSource" that could
    sometimes cause an abort if more than one Elementary Stream
    Source were multiplexed into a single Transport Stream.
    (Thanks to Marc Palau for reporting this issue.)
- version 2015.01.19:
  * Fixed an obscure bug in "RTSPClient" that might conceivably
    have caused a crash if it received a completely empty RTSP
    response.
- version 2015.01.04:
  * Updated "config.iphone-simulator" to work with the latest Xcode.
    (Thanks to Braden Ackerman.)
  * In the "BasicUsageEnvironment" implementation, renamed
    "EventTime" to "_EventTime" to avoid a reported naming conflict.
- version 2014.12.17:
  * Updated "RTSPServerSupportingHTTPStreaming" to make sure that
    the data stream source gets closed when it's no longer needed.
- version 2014.12.16:
  * Changed the FD_SETSIZE check (introduced in version 2014.12.11)
    so that it's not done in Windows (because in Windows,
    FD_SETSIZE has different semantics).
    (Thanks to Deanna Earley for reporting this.)
- version 2014.12.13:
  * Updated the H.264/H.265 parsing code in "H264or5VideoStreamFramer"
    to be a little smarter about how it computes a file's frame rate
    (when streaming a 'raw' H.264 or H.265 file).
    (Thanks to Michel Promonet for inspiring this.)
  * Updated "config.iphoneos" to work with the latest Xcode.
    (Thanks to Braden Ackerman.)
- version 2014.12.11:
  * Changed our implementation of "setBackgroundHandling()" and
    "moveBackgroundHandling()" in "BasicTaskScheduler" to check for
    (and disallow) socket numbers >= FD_SETSIZE, because <sys/select.h>
    has a bug (at least, in most systems) that causes buffer overflow
    in this case.  (Thanks to Michel Promonet for pointing this out.)
- version 2014.12.09:
  * Needed to make the "QuickTimeFileSink" constructor and destructor
    protected: to allow subclassing.
- version 2014.12.08:
  * Fixed a bug in parsing 'absolute' RTSP "Range:" headers with no end
    time. (Thanks to Ken Chow for reporting this.)
  * Added a new option "-K" to "openRTSP, to tell the client to
    periodically send "OPTIONS" requests as 'keep-alives' for buggy
    servers that don't use incoming RTCP "RR" packets to indicate client
    liveness.  (Thanks to Peter Schlaile for this suggestion.)
  * Added a new 'protected' virtual member function "noteRecordedFrame()"
    to "QuickTimeFileSink". This function is called whenever a frame is
    recorded to the output file. The default implementation of this
    virtual function does nothing, but subclasses can redefine it if
    they wish.
- version 2014.11.28:
  * When "RTSPClient" parses a RTSP response, we first skip over any
    blank lines that may be at the start of the response.  This can
    happen if the previous response (e.g., to a "DESCRIBE") contained
    extra whitespace. (Thanks to ilwoo Nam for giving an example of
    a server that exhibited this behavior.)
- version 2014.11.12:
  * We had forgotten to initialize the "RTSPClient" member variable
  "fAllowBasicAuthentication" that we introduced in the previous
  version.
- version 2014.11.07:
  * Added a new "RTSPClient" member function "disallowBasicAuthentication()"
    that you can call if you don't want a RTSP client to perform 'basic'
    authentication (whcih involves sending the username and password over
    the network), even if the server asks for this.
    (Thanks to Tomasz Pala for this suggestion.)
  * Updated the debugging printout code in "RTCP.cpp" to identify all
    known RTCP payload types, even if we don't currently handle them.
    We also - when doing debugging printout - parse and print out
    the contents of SDES RTCP packets.
- version 2014.11.01:
  * Updated "RTSPClient" so that it reuses "fCurrentAuthenticator"
    if we previously updated it with data from a "WWW-Authenticate:"
    response, even if a non_NULL "authenticator" parameter was
    passed as a parameter to the command.  This reduces the number
    of authetication exchanges that take place if the server asks
    for authentication on more than one command in a RTSP session.
    (Thanks to Tomasz Pala for this suggestion.)
  * Updated "DigestAuthenticator" to allow for the possibility of
    "username" or "password" being NULL.
  * Updated the "RTSPServer" implementation to add an access check
    before the first "SETUP" (the one that doesn't include a
    session id), because it's possible, in principle, for a client
    to send such a "SETUP" without first sending a "DESCRIBE".
    Therefore, we need to perform access checks on both commands.
- version 2014.10.28:
  * Added support for the VP9 video RTP payload format (sending and
    receiving), including the demultiplexing and streaming of a VP9
    video track from a Matroska-format file.
  * Made "VP8VideoRTPSource" more robust against a bad first-byte
    header field in the payload.
- version 2014.10.21:
  * Increased the max output packet size for "MultiFramedRTPSink"
    and "RTCPInstance" from 1448 to 1456, because we had a report
    of problems when proxying incoming JPEG/RTP packets of this
    size (and because 1456 bytes still gives a packet size of no
    more than 1500 bytes when we add
    in IP, UDP, and UMTP headers).
- version 2014.10.20:
  * Increased the RTSP request and response buffer sizes from 10000
    to 20000 bytes, because we saw a RTSP stream (VP8 video) that
    had an extremely large "configuration=" string that was hiting
    the previous limit.
- version 2014.10.16:
  * Fixed the "RTSPServer" implementation to handle a rare race
    condition that could cause a "ServerMediaSession" object to
    be deleted while it was being used to implement "DESCRIBE".
    (Thanks to Michel Promonet for reporting this.)
- version 2014.10.07:
  * Fixed a bug in the "MultiFramedRTPSource" implementation where
    we weren't properly checking the size of incoming RTP packets
    that have the "CC" field (i.e., number of "CSRC" fields) non-zero.
  * Updated "Groupsock::output()" to be a virtual function.
    (This makes it possible to implement "Groupsock" subclasses that
    implement 'bump-in-the-stack' protocols (such as SRT(C)P) below
    RTP/RTCP.)
- version 2014.10.03:
  * Fixed a problem in the "timestampString()" routine that occurs
    if "time_t" is 64 bits, but we're on a 32-bit machine.
    (Thanks to Deanna Earley for reporting this.)
  * Updated the debugging output code in "RTCP.cpp" to make it
    clearer that SDES and APP packets are not invalid; just not
    (yet) handled by us.
* Wed Oct 29 2014 olaf@aepfle.de
- BuildRequire pkg-config to get rpm Provides/Requires pkgconfig(live555)
* Mon Oct  6 2014 aloisio@gmx.com
- Added support for pkg-config by creating the relevant .pc file
* Thu Oct  2 2014 dimstar@opensuse.org
- Update to 2014.09.22:
  + Changed the way in which the "RTSPServer" code handles incoming
    "OPTIONS" commands that contain a "Session:" header. If the
    "Session:" header contains a session id that does not exist,
    then we now return a "Session Not Found" error (even though the
    handling of the "OPTIONS" command is not session-specific).
    This new behavior will help proxy servers (that use our
    "RTSPServer" implementation as a 'back-end' server) better
    detect when the back-end server has restarted while streaming.
  + For all other changes since 2013.04.30, please see
    http://www.live555.com/liveMedia/public/changelog.txt.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 2013.04.30:
  + One year worth of updates... see changelog.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 2012.02.04:
  + Updated "WAVAudioFileSource" to read from its input file
    asynchronously, if possible, rather than doing a synchronous
    (blocking) read.
- Changes from version 2012.02.03:
  + Updated "RTSPClient" to - after receiving a "SETUP" response
    for a UDP stream - send a couple of short 'dummy' UDP packets
    to the server.  This will make it more likely that the
    incoming RTP/UDP packets will successfully traverse a NAT box
    (if the client is behind a NAT).  (Note that we don't do this
    for RTCP, because the client's regular RTCP "RR" packets will
    have the same effect.)
  + Changed the way that the "sessionId" member field in
    "MediaSubsession" is managed.  Its memory is now managed by
    "MediaSubsession" itself, rather than by "RTSPClient" (as it
    was previously).  With the previous behavior, "valgrind"
    (incorrectly) reported a possible memory leak. The new behavior
    should make 'valgrinerds' happy.
- Drop patches that were required by VideoLAN: fixed upstream:
  + live-getaddrinfo.patch
  + live-inet_ntop.patch
  + live-uselocale.patch
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 2012.01.26.
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Rewrite part of the .spec file.., Cleaner installation.
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Add VideoLAN required patches for proper funtioning of live555:
  + live-getaddrinfo.patch
  + live-inet_ntop.patch
  + live-uselocale.patch
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.11.08:
  + Added "VorbisAudioRTPSink" and "VorbisAudioRTPSource" for
    sending/receiving Vorbos audio RTP streams (based on RFC 5215).
  + Added "VP8VideoRTPSink" and "VP8VideoRTPSource" for
    sending/receiving VP8 video RTP streams.
  + Added support for extracting and streaming Vorbis audio tracks
    from Matroska (including WEBM) files.
  + Added support for extracting and streaming VP8 video tracks
    from Matroska (including WEBM) files.
  + Updated the "testOnDemandRTSPServer" and "LIVE555MediaServer"
    (source-code version only) applications to support streaming
    from ".webm' files.
  + Fixed frame durations for data extracted from Matroska tracks
    that don't have a 'default duration'.
  + Fixed a memory leak in "RTSPClient::sendOptionsCmd()".
* Sat Oct 22 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.10.18:
  + Improved "RTSPServer" support for subdirectories in "rtsp://"
  URLs (handling this better for non-compliant clients that try to
  do a "SETUP" on agrregate URLs - when there is only a single
  subsession in the stream).
- Add a -devel subpackage, obsolete the now empty subpackage by it.
- Drop rpmlintrc file, as the devel files are now in a devel
  package.
* Thu Jun 30 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.06.16
* Sat Oct  2 2010 dominique-vlc.suse@leuenberger.net
- Update to 2010.09.25
* Mon Aug 31 2009 dominique-vlc.suse@leuenberger.net
  2009.07.28:
- Updated "QuickTimeFileSink" to add a "stss" atom for video streams, following a suggestion by Gerardo Ares.
  (At present we just 'guess' which video 'samples' (frames) are 'key frames', so this might not work properly on some
  video streams.)
- Modified the "config.uClinux" configuration file, following a suggestion by Chetan Raj.
- Changed "RTSPClient"s implementation of the RTSP "TEARDOWN" command to always act as if the command succeeded, regardless of
  the actual response from the server (because, from the client's point of view, the session has ended).
  (This overcomes a potential memory leak, pointer out by Stuart Rawling.)
  2009.07.09:
- Modified the RTSP server implementation to - for streams where there is a known duration - always include a range end time
  in the RTSP "PLAY" response, even if the client did not specify one in the "PLAY" request.  This allows VLC's client
  'trick play' to (mostly) work.
- Updated "MediaSession::initiate()" to eliminate a possible memory leak if we get an error in socket creation.
  (Thanks to Denis Charmet.)
- Made a minor change to "MultiFramedRTPSink" to make monitoring/debugging easier.  (Thanks to Guy Bonneau.)
- Begun adding support for DV video.  However, this implementation is still incomplete.  DO NOT USE IT!
  2009.06.02:
- Updated the MPEG Transport Stream multiplexor implementation to allow for H.264 video.  (Thanks to Massimo Zito.)
- Updated "MultiFramedRTPSink" to allow for subclasses for RTP payload formats (such as DV, coming soon) that impose
  a granularity on RTP fragment sizes.
* Sun Apr 26 2009 dominique-suse.vlc@leuenberger.net
  2009.04.20:
- Fixed "BasicUsageEnvironment::getErrno()" to always (under Windows) return
  "WSAGetLastError()" (and to just ignore the "errno" variable>.
  Also fixed a few places in the code where we were still using "errno"
  instead of calling "getErrno()"
  2009.04.07:
- Changed many "char*" variables to "char const*" to eliminate possible compiler warnings.
  (Thanks to Sebastien Escudier for pointing out this issue.)
  2009.04.06:
- Modified our Windows-only version of "gettimeofday()" so that it now returns times based on the proper epoch.
  (Thanks to Patrick White for this suggestion.)
- Created a new config file for 64-bit Solaris, and renamed the old "config.solaris" file to make it
  clear that it's for 32-bit Solaris only.  (Thanks to ichael Skaastrup.)
- Modified "config.mingw" to add "-DLOCALE_NOT_USED" to the "COMPILE_OPTS =" line.  (The VLC folks seem to want
  this.)
- Made a minor change to some win32-specific code in "RTSPClient.cpp" that the VLC folks seem to like.
  (However, "RTSPClient" is about to undergo a major overhaul (for asynchronous I/O) anyway...)
- Made a small change to "mediaServer/DynamicRTSPServer.cpp" to eliminate compiler warnings on some platforms.
